A recipe is a set of instructions for downloading and processing the input data
(see [available
datasets](https://zampy.readthedocs.io/en/latest/available_datasets/)). Recipes
are used to create pre-processing steps in a consistent and transparent way.
Recipe format is usullay ``.yml`` and is stored in the [recipes
folder](https://github.com/EcoExtreML/zampy/tree/main/recipes). To know how to
run a recipe, see [Getting started](https://zampy.readthedocs.io/en/latest/).
The following recipes are available:

- `STEMMUS_SCOPE_input.yml`: this recipe can be used to download and prepare
  some of the input data required by [STEMMUS_SCOPE
  model](https://github.com/EcoExtreML/STEMMUS_SCOPE).
